/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PkiSecretBackendConfigCmpv2Config extends cdktf.TerraformMetaArguments {
    /**
    * Fields parsed from the CSR that appear in the audit and can be used by sentinel policies
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#audit_fields PkiSecretBackendConfigCmpv2#audit_fields}
    */
    readonly auditFields?: string[];
    /**
    * The PKI secret backend the resource belongs to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#backend PkiSecretBackendConfigCmpv2#backend}
    */
    readonly backend: string;
    /**
    * Can be sign-verbatim or a role given by role:<role_name>
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#default_path_policy PkiSecretBackendConfigCmpv2#default_path_policy}
    */
    readonly defaultPathPolicy?: string;
    /**
    * A comma-separated list of validations not to perform on CMPv2 messages.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#disabled_validations PkiSecretBackendConfigCmpv2#disabled_validations}
    */
    readonly disabledValidations?: string[];
    /**
    * If set, parse out fields from the provided CSR making them available for Sentinel policies
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#enable_sentinel_parsing PkiSecretBackendConfigCmpv2#enable_sentinel_parsing}
    */
    readonly enableSentinelParsing?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether CMPv2 is enabled
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#enabled PkiSecretBackendConfigCmpv2#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#id PkiSecretBackendConfigCmpv2#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Target namespace. (requires Enterprise)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#namespace PkiSecretBackendConfigCmpv2#namespace}
    */
    readonly namespace?: string;
    /**
    * authenticators block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#authenticators PkiSecretBackendConfigCmpv2#authenticators}
    */
    readonly authenticators?: PkiSecretBackendConfigCmpv2Authenticators;
}
export interface PkiSecretBackendConfigCmpv2Authenticators {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#cert PkiSecretBackendConfigCmpv2#cert}
    */
    readonly cert?: {
        [key: string]: string;
    };
}
export declare function pkiSecretBackendConfigCmpv2AuthenticatorsToTerraform(struct?: PkiSecretBackendConfigCmpv2AuthenticatorsOutputReference | PkiSecretBackendConfigCmpv2Authenticators): any;
export declare function pkiSecretBackendConfigCmpv2AuthenticatorsToHclTerraform(struct?: PkiSecretBackendConfigCmpv2AuthenticatorsOutputReference | PkiSecretBackendConfigCmpv2Authenticators): any;
export declare class PkiSecretBackendConfigCmpv2AuthenticatorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PkiSecretBackendConfigCmpv2Authenticators | undefined;
    set internalValue(value: PkiSecretBackendConfigCmpv2Authenticators | undefined);
    private _cert?;
    get cert(): {
        [key: string]: string;
    };
    set cert(value: {
        [key: string]: string;
    });
    resetCert(): void;
    get certInput(): {
        [key: string]: string;
    } | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2 vault_pki_secret_backend_config_cmpv2}
*/
export declare class PkiSecretBackendConfigCmpv2 extends cdktf.TerraformResource {
    static readonly tfResourceType = "vault_pki_secret_backend_config_cmpv2";
    /**
    * Generates CDKTF code for importing a PkiSecretBackendConfigCmpv2 resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PkiSecretBackendConfigCmpv2 to import
    * @param importFromId The id of the existing PkiSecretBackendConfigCmpv2 that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PkiSecretBackendConfigCmpv2 to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/vault/5.1.0/docs/resources/pki_secret_backend_config_cmpv2 vault_pki_secret_backend_config_cmpv2} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PkiSecretBackendConfigCmpv2Config
    */
    constructor(scope: Construct, id: string, config: PkiSecretBackendConfigCmpv2Config);
    private _auditFields?;
    get auditFields(): string[];
    set auditFields(value: string[]);
    resetAuditFields(): void;
    get auditFieldsInput(): string[] | undefined;
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    private _defaultPathPolicy?;
    get defaultPathPolicy(): string;
    set defaultPathPolicy(value: string);
    resetDefaultPathPolicy(): void;
    get defaultPathPolicyInput(): string | undefined;
    private _disabledValidations?;
    get disabledValidations(): string[];
    set disabledValidations(value: string[]);
    resetDisabledValidations(): void;
    get disabledValidationsInput(): string[] | undefined;
    private _enableSentinelParsing?;
    get enableSentinelParsing(): boolean | cdktf.IResolvable;
    set enableSentinelParsing(value: boolean | cdktf.IResolvable);
    resetEnableSentinelParsing(): void;
    get enableSentinelParsingInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastUpdated(): string;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _authenticators;
    get authenticators(): PkiSecretBackendConfigCmpv2AuthenticatorsOutputReference;
    putAuthenticators(value: PkiSecretBackendConfigCmpv2Authenticators): void;
    resetAuthenticators(): void;
    get authenticatorsInput(): PkiSecretBackendConfigCmpv2Authenticators | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
